Enum polkadot_node_primitives::approval::AssignmentCertKind [−][src]
pub enum AssignmentCertKind {
RelayVRFModulo {
sample: u32,
},
RelayVRFDelay {
core_index: CoreIndex,
},
}Expand description
Different kinds of input data or criteria that can prove a validator’s assignment to check a particular parachain.
Variants
An assignment story based on the VRF that authorized the relay-chain block where the candidate was included combined with a sample number.
The context used to produce bytes is RELAY_VRF_MODULO_CONTEXT
Fields of RelayVRFModulo
sample: u32The sample number used in this cert.
An assignment story based on the VRF that authorized the relay-chain block where the candidate was included combined with the index of a particular core.
The context is RELAY_VRF_DELAY_CONTEXT
Fields of RelayVRFDelay
core_index: CoreIndexThe core index chosen in this cert.