Struct polkadot_node_primitives::disputes::DisputeMessage [−][src]
pub struct DisputeMessage(_);Expand description
A dispute initiating/participating message that is guaranteed to have been built from signed statements.
And most likely has been constructed correctly. This is used with
DisputeDistributionMessage::SendDispute for sending out votes.
Implementations
pub fn from_signed_statements(
valid_statement: SignedDisputeStatement,
valid_index: ValidatorIndex,
invalid_statement: SignedDisputeStatement,
invalid_index: ValidatorIndex,
candidate_receipt: CandidateReceipt,
session_info: &SessionInfo
) -> Result<Self, Error>
pub fn from_signed_statements(
valid_statement: SignedDisputeStatement,
valid_index: ValidatorIndex,
invalid_statement: SignedDisputeStatement,
invalid_index: ValidatorIndex,
candidate_receipt: CandidateReceipt,
session_info: &SessionInfo
) -> Result<Self, Error>
Build a SignedDisputeMessage and check what can be checked.
This function checks that:
- both statements concern the same candidate
- both statements concern the same session
- the invalid statement is indeed an invalid one
- the valid statement is indeed a valid one
- The passed
CandidateReceipthas the correct hash (as signed in the statements). - the given validator indices match with the given
ValidatorIds in the statements, given aSessionInfo.
We don’t check whether the given SessionInfo matches the SessionIndex in the
statements, because we can’t without doing a runtime query. Nevertheless this smart
constructor gives relative strong guarantees that the resulting SignedDisputeStatement is
valid and good. Even the passed SessionInfo is most likely right if this function
returns Some, because otherwise the passed ValidatorIds in the SessionInfo at
their given index would very likely not match the ValidatorIds in the statements.
So in summary, this smart constructor should be smart enough to prevent from almost all programming errors that one could realistically make here.
Read only access to the candidate receipt.
Read only access to the SessionIndex.
Read only access to the invalid vote.
Read only access to the valid vote.