Enum polkadot_node_primitives::Statement [−][src]
pub enum Statement {
Seconded(CommittedCandidateReceipt),
Valid(CandidateHash),
}Expand description
A statement, where the candidate receipt is included in the Seconded variant.
This is the committed candidate receipt instead of the bare candidate receipt. As such, it gives access to the commitments to validators who have not executed the candidate. This is necessary to allow a block-producing validator to include candidates from outside the para it is assigned to.
Variants
Seconded(CommittedCandidateReceipt)A statement that a validator seconds a candidate.
Tuple Fields of Seconded
Valid(CandidateHash)A statement that a validator has deemed a candidate valid.
Tuple Fields of Valid
Implementations
Get the candidate hash referenced by this statement.
If this is a Statement::Seconded, this does hash the candidate receipt, which may be expensive
for large candidates.
Transform this statement into its compact version, which references only the hash of the candidate.